@@ -10,11 +10,12 @@ from typing import List, Optional, Sequence, Tuple
 from phylum import __version__
 from phylum.ci import SCRIPT_NAME
 from phylum.ci.ci_base import CIBase, CIEnvs
+from phylum.ci.ci_github import CIGitHub
 from phylum.ci.ci_gitlab import CIGitLab
 from phylum.ci.ci_none import CINone
 from phylum.ci.ci_precommit import CIPreCommit
 from phylum.ci.common import ReturnCode
-from phylum.constants import SUPPORTED_TARGET_TRIPLES, TOKEN_ENVVAR_NAME
+from phylum.constants import TOKEN_ENVVAR_NAME
 from phylum.init.cli import get_target_triple, version_check
 
 
@@ -27,6 +28,11 @@ def detect_ci_platform(args: argparse.Namespace, remainder: List[str]) -> CIBase
         print(" [+] CI environment detected: GitLab CI")
         ci_envs.append(CIGitLab(args))
 
+    # Detect GitHub Actions
+    if os.getenv("GITHUB_ACTIONS") == "true":
+        print(" [+] CI environment detected: GitHub Actions")
+        ci_envs.append(CIGitHub(args))
+
     # Detect Python pre-commit environment
     # This might be a naive strategy for detecting the `pre-commit` case, but there is at least
     # an attempt, via a pre-requisite check, to ensure all the extra arguments are staged files.
@@ -182,7 +188,6 @@ def get_args(args: Optional[Sequence[str]] = None) -> Tuple[argparse.Namespace,
     cli_group.add_argument(
         "-t",
         "--target",
-        choices=SUPPORTED_TARGET_TRIPLES,
         default=get_target_triple(),
         help="The target platform type where the CLI will be installed.",
     )
