@@ -5,7 +5,7 @@ import textwrap
 from phylum.ci.common import RiskDomain
 
 # The common Phylum header that must exist as the first text in the first line of all analysis output
-PHYLUM_HEADER = "## Phylum OSS Supply Chain Risk Analysis"
+PHYLUM_HEADER = "# Phylum OSS Supply Chain Risk Analysis"
 
 # NOTE: All multi-line strings are indented by two levels on purpose, to ensure they line up correctly when used with
 #       each other in templates and are all fully left justified after applying `textwrap.dedent` for normalization.
@@ -79,7 +79,7 @@ INCOMPLETE_COMMENT_TEMPLATE = string.Template(
 #   * key name returned from a Phylum analysis as known by the overall project threshold mapping
 #   * key name returned from a Phylum analysis as known by an individual package riskVectors mapping
 PROJECT_THRESHOLD_OPTIONS = {
-    "vul_threshold": RiskDomain("Software Vulnerability", "vulnerability", "vulnerability"),
+    "vul_threshold": RiskDomain("Software Vulnerability", "vulnerability", "vulnerabilities"),
     "mal_threshold": RiskDomain("Malicious Code", "malicious", "malicious_code"),
     "eng_threshold": RiskDomain("Engineering", "engineering", "engineering"),
     "lic_threshold": RiskDomain("License", "license", "license"),
